@@ -17,7 +17,7 @@
 
 __author__ = 'Ahmet Bakan'
 __copyright__ = 'Copyright (C) 2010-2012 Ahmet Bakan'
-__version__ = '1.3.1'
+__version__ = '1.4'
 
 release = [int(x) for x in __version__.split('.')]
 
@@ -27,9 +27,8 @@ import os.path
 import platform
 import warnings
 
-if not (2, 6) <= sys.version_info[:2] <= (2, 7):
-    raise Exception("prody is compatible with Python 2.6 and 2.7, you are "
-                      "using Python " + platform.python_version())
+if sys.version_info[:2] < (2, 6):
+    raise Exception('prody is compatible with Python version less than 2.6')
 
 try:
     import numpy as np
@@ -39,8 +38,8 @@ else:
     if tuple(map(int, np.__version__.split('.')[:2])) < (1, 4):
         raise ImportError('Numpy v1.4 or later is required for ProDy')
 
-from utilities import USERHOME, PackageLogger, PackageSettings
-from utilities import getPackagePath, joinRepr, tabulate
+from .utilities import USERHOME, PackageLogger, PackageSettings
+from .utilities import getPackagePath, joinRepr, tabulate
 
 DEPRECATION_WARNINGS = False
 
@@ -113,6 +112,16 @@ from .measure import *
 __all__.extend(measure.__all__)
 __all__.append('measure')
 
+from . import database
+from .database import *
+__all__.extend(database.__all__)
+__all__.append('database')
+
+from . import sequence
+from .sequence import *
+__all__.extend(sequence.__all__)
+__all__.append('sequence')
+
 from . import dynamics
 from .dynamics import *
 __all__.extend(dynamics.__all__)
@@ -135,6 +144,7 @@ __all__.append('prody')
 CONFIGURATION = {
     'backup': (False, None, None),
     'backup_ext': ('.BAK', None, None),
+    'auto_show': (True, None, None),
     'ligand_xml_save': (False, None, None),
     'typo_warnings': (True, None, None),
     'check_updates': (0, None, None),
